@@ -11,7 +11,11 @@ class HFDataset(BaseDataset):
 
     @staticmethod
     def create_dataset(
-        request: _Request, name: str, hf_id: str, hf_token: str, key: Optional[str] = None
+        request: _Request,
+        name: str,
+        hf_id: str,
+        hf_token: Optional[str] = None,
+        key: Optional[str] = None,
     ):
         params = {
             "name": name,
