@@ -1,5 +1,6 @@
 """ Dataset entity """
 from dataclasses import dataclass
+from typing import Optional
 
 
 @dataclass
@@ -32,10 +33,10 @@ class HFDatasetEntity(BaseDatasetEntity):
     """Hugging Face Dataset entity"""
 
     hf_id: str
-    hf_token: str
+    hf_token: Optional[str]
 
     def __init__(  # pylint: disable=redefined-builtin
-        self, name: str, hf_id: str, hf_token: str, id: str
+        self, name: str, hf_id: str, hf_token: Optional[str], id: str
     ) -> None:
         self.hf_id = hf_id
         self.hf_token = hf_token
