@@ -1,7 +1,7 @@
 """Test entity"""
 import logging
 from dataclasses import dataclass
-from typing import Dict, List
+from typing import Dict, List, Union
 
 from ..Helpers import URLUtils
 
@@ -15,22 +15,26 @@ class TestEntity:
     id: str
     name: str
     model_key: str
-    dataset_id: str
+    dataset_id: Union[str, None]
     test_type: str
     attacks: List[Dict]
     config: List[Dict]
     report_ui_url: str
+    guardrail_model_key: str
+    target_model_key: str
 
     def __init__(  # pylint: disable=redefined-builtin
         self,
         id: str,
         name: str,
         model_key: str,
-        dataset_id: str,
+        dataset_id: Union[str, None],
         test_type: str,
         attacks: List[Dict],
         config: List[Dict],
         api_host: str,
+        guardrail_model_key: str,
+        target_model_key: str,
     ) -> None:
         self.id = id
         self.name = name
@@ -41,3 +45,5 @@ class TestEntity:
         self.config = config
         self.report_ui_url = URLUtils.get_test_report_ui_url(api_host, id)
         logger.info("Report UI URL: %s", self.report_ui_url)
+        self.guardrail_model_key = guardrail_model_key
+        self.target_model_key = target_model_key
